| BRANCH | STATUS |
|---|---|
| master | [![Unit-Testing, Coverage, Linting](https://github.com/btr1975/nso_jsonrpc_requester/actions/workflows/test-coverage-lint.yml/badge.svg?branch=master)](https://github.com/btr1975/nso_jsonrpc_requester/actions/workflows/test-coverage-lint.yml) |
| develop | [![Unit-Testing, Coverage, Linting](https://github.com/btr1975/nso_jsonrpc_requester/actions/workflows/test-coverage-lint.yml/badge.svg?branch=develop)](https://github.com/btr1975/nso_jsonrpc_requester/actions/workflows/test-coverage-lint.yml) |


[![Downloads](https://pepy.tech/badge/nso-jsonrpc-requester)](https://pepy.tech/project/nso-jsonrpc-requester)
[![Supported Versions](https://img.shields.io/pypi/pyversions/nso-jsonrpc-requester.svg)](https://pypi.org/project/nso-jsonrpc-requester)

# nso_jsonrpc_requester

* This is a library to interact with the JSON-RPC of a Cisco Network
  Services Orchestrator server.

* This is not a 100% complete library it contains what I use most.

* **THIS IS NOT MEANT TO BE PRODUCTION READY SO TEST WHAT YOU WANT TO USE IT FOR**

### Library in Other Languages

* [Python 3](https://github.com/btr1975/nso_jsonrpc_requester)
* [Go](https://github.com/btr1975/nsojsonrpcrequestergo)
* I try to keep the functionality the same between both, because I use
  both.

### Go Install

* Install newest code

```shell
go get github.com/btr1975/nsojsonrpcrequestergo
```

* Install specific version example

```shell
go get github.com/btr1975/nsojsonrpcrequestergo@v1.0.0
```

### Python Install Source

* In your requirements.txt for newest code

```text
git+https://github.com/btr1975/nso_jsonrpc_requester.git@master#egg=nso_jsonrpc_requester
```

* In your requirements.txt for specific version

```text
git+https://github.com/btr1975/nso_jsonrpc_requester.git@1.0.3#egg=nso_jsonrpc_requester
```

### Python Install pip

```text
pip install nso-jsonrpc-requester
```

